package alx.p06_funkcje.przyklady;

public class JednostkiMiary {
	
	public static double kmNaMile(double km) {
		return km / 1.609344;
	}
	
	public static double mileNaKm(double mile) {
		return 1.609344 * mile;
	}
	
	public static double farNaCel(double far) {
		return 5. / 9. * (far - 32d);
	}
	
	public static double celNaFar(double cel) {
		return 32.0 + (9.0 / 5.0 * cel);  // 32 + 1.8*cel
	}

}
